@@ -25,10 +25,8 @@
 #define LIBXFCE4UTIL_INSIDE_LIBXFCE4UTIL_H
 
 #include <libxfce4util/libxfce4util-config.h>
-#include <libxfce4util/libxfce4util-enum-types.h>
 
-#include <libxfce4util/debug.h>
-#include <libxfce4util/xfce-desktopentry.h>
+#include <libxfce4util/xfce-debug.h>
 #include <libxfce4util/xfce-fileutils.h>
 #include <libxfce4util/xfce-generics.h>
 #include <libxfce4util/xfce-i18n.h>
