@@ -28,7 +28,7 @@
 
 #include <glib.h>
 
-#include <libxfce4util/debug.h>
+#include <libxfce4util/xfce-debug.h>
 
 G_BEGIN_DECLS
 
