@@ -29,27 +29,33 @@ typedef struct _XfceRcSimple XfceRcSimple;
 
 struct _XfceRc
 {
-  void (*close) (XfceRc *rc);
-  void (*flush) (XfceRc *rc);
-  void (*rollback) (XfceRc *rc);
-  gboolean (*is_dirty) (const XfceRc *rc);
-  gboolean (*is_readonly) (const XfceRc *rc);
-  gchar** (*get_groups) (const XfceRc *rc);
-  gchar** (*get_entries) (const XfceRc *rc, const gchar *group);
-  void (*delete_group) (XfceRc *rc, const gchar *group, gboolean global);
-  const gchar* (*get_group) (const XfceRc *rc);
-  gboolean (*has_group) (const XfceRc *rc, const gchar *group);
-  void (*set_group) (XfceRc *rc, const gchar *group);
-  void (*delete_entry) (XfceRc *rc, const gchar *key, gboolean global);
-  gboolean (*has_entry) (const XfceRc *rc, const gchar *key);
-  const gchar* (*read_entry) (const XfceRc *rc, const gchar *key,
-                              gboolean translated);
+  void          (*close)        (XfceRc       *rc);
+  void          (*flush)        (XfceRc       *rc);
+  void          (*rollback)     (XfceRc       *rc);
+  gboolean      (*is_dirty)     (const XfceRc *rc);
+  gboolean      (*is_readonly)  (const XfceRc *rc);
+  gchar       **(*get_groups)   (const XfceRc *rc);
+  gchar       **(*get_entries)  (const XfceRc *rc,
+                                 const gchar  *group);
+  void          (*delete_group) (XfceRc       *rc,
+                                 const gchar  *group, gboolean global);
+  const gchar  *(*get_group)    (const XfceRc *rc);
+  gboolean      (*has_group)    (const XfceRc *rc,
+                                 const gchar  *group);
+  void          (*set_group)    (XfceRc       *rc,
+                                 const gchar  *group);
+  void          (*delete_entry) (XfceRc       *rc,
+                                 const gchar *key,
+                                 gboolean     global);
+  gboolean      (*has_entry)    (const XfceRc *rc,
+                                 const gchar  *key);
+  const gchar  *(*read_entry)   (const XfceRc *rc,
+                                 const gchar  *key,
+                                 gboolean      translated);
   /* write_entry == NULL means readonly */
-  void (*write_entry) (XfceRc *rc, const gchar *key, const gchar *value);
-  void (*reserved1) (void);
-  void (*reserved2) (void);
-  void (*reserved3) (void);
-  void (*reserved4) (void);
+  void          (*write_entry)  (XfceRc       *rc,
+                                 const gchar  *key,
+                                 const gchar  *value);
 
   gchar   *locale;
 };
@@ -64,8 +70,8 @@ struct _XfceRc
 G_GNUC_INTERNAL void          _xfce_rc_init               (XfceRc       *rc);
 
 G_GNUC_INTERNAL XfceRcSimple* _xfce_rc_simple_new         (XfceRcSimple *shared,
-                                           const gchar  *filename,
-                                           gboolean      readonly);
+                                                           const gchar  *filename,
+                                                           gboolean      readonly);
 G_GNUC_INTERNAL gboolean      _xfce_rc_simple_parse       (XfceRcSimple *simple);
 G_GNUC_INTERNAL void          _xfce_rc_simple_close       (XfceRc       *rc);
 G_GNUC_INTERNAL void          _xfce_rc_simple_flush       (XfceRc       *rc);
@@ -75,30 +81,30 @@ G_GNUC_INTERNAL gboolean      _xfce_rc_simple_is_readonly (const XfceRc *rc) G_G
 G_GNUC_INTERNAL const gchar*  _xfce_rc_simple_get_filename(const XfceRc *rc) G_GNUC_CONST;
 G_GNUC_INTERNAL gchar**       _xfce_rc_simple_get_groups  (const XfceRc *rc) G_GNUC_CONST;
 G_GNUC_INTERNAL gchar**       _xfce_rc_simple_get_entries (const XfceRc *rc,
-                                           const gchar  *name) G_GNUC_CONST;
+                                                           const gchar  *name) G_GNUC_CONST;
 G_GNUC_INTERNAL void          _xfce_rc_simple_delete_group(XfceRc       *rc,
-                                           const gchar  *name,
-                                           gboolean      global);
-const gchar*  _xfce_rc_simple_get_group   (const XfceRc *rc) G_GNUC_CONST;
+                                                           const gchar  *name,
+                                                           gboolean      global);
+G_GNUC_INTERNAL const gchar*  _xfce_rc_simple_get_group   (const XfceRc *rc) G_GNUC_CONST;
 G_GNUC_INTERNAL gboolean      _xfce_rc_simple_has_group   (const XfceRc *rc,
-                                           const gchar  *name) G_GNUC_CONST;
+                                                           const gchar  *name) G_GNUC_CONST;
 G_GNUC_INTERNAL void          _xfce_rc_simple_set_group   (XfceRc       *rc,
-                                           const gchar  *name);
+                                                           const gchar  *name);
 G_GNUC_INTERNAL void          _xfce_rc_simple_delete_entry(XfceRc       *rc,
-                                           const gchar  *key,
-                                           gboolean      global);
+                                                           const gchar  *key,
+                                                           gboolean      global);
 G_GNUC_INTERNAL gboolean      _xfce_rc_simple_has_entry   (const XfceRc *rc,
-                                           const gchar  *key) G_GNUC_CONST;
+                                                           const gchar  *key) G_GNUC_CONST;
 G_GNUC_INTERNAL const gchar*  _xfce_rc_simple_read_entry  (const XfceRc *rc,
-                                           const gchar  *key,
-                                           gboolean      translated) G_GNUC_CONST;
+                                                           const gchar  *key,
+                                                           gboolean      translated) G_GNUC_CONST;
 G_GNUC_INTERNAL void          _xfce_rc_simple_write_entry (XfceRc       *rc,
-                                           const gchar  *key,
-                                           const gchar  *value);
+                                                           const gchar  *key,
+                                                           const gchar  *value);
 
 G_GNUC_INTERNAL XfceRcConfig* _xfce_rc_config_new         (XfceResourceType type,
-                                           const gchar  *resource,
-                                           gboolean      readonly);
+                                                           const gchar  *resource,
+                                                           gboolean      readonly);
 G_GNUC_INTERNAL void          _xfce_rc_config_close       (XfceRc       *rc);
 G_GNUC_INTERNAL void          _xfce_rc_config_flush       (XfceRc       *rc);
 G_GNUC_INTERNAL void          _xfce_rc_config_rollback    (XfceRc       *rc);
@@ -106,26 +112,26 @@ G_GNUC_INTERNAL gboolean      _xfce_rc_config_is_dirty    (const XfceRc *rc) G_G
 G_GNUC_INTERNAL gboolean      _xfce_rc_config_is_readonly (const XfceRc *rc) G_GNUC_CONST;
 G_GNUC_INTERNAL gchar**       _xfce_rc_config_get_groups  (const XfceRc *rc) G_GNUC_CONST;
 G_GNUC_INTERNAL gchar**       _xfce_rc_config_get_entries (const XfceRc *rc,
-                                           const gchar  *name) G_GNUC_CONST;
+                                                           const gchar  *name) G_GNUC_CONST;
 G_GNUC_INTERNAL void          _xfce_rc_config_delete_group(XfceRc       *rc,
-                                           const gchar  *name,
-                                           gboolean      global);
+                                                           const gchar  *name,
+                                                           gboolean      global);
 G_GNUC_INTERNAL const gchar*  _xfce_rc_config_get_group   (const XfceRc *rc) G_GNUC_CONST;
 G_GNUC_INTERNAL gboolean      _xfce_rc_config_has_group   (const XfceRc *rc,
-                                           const gchar  *name) G_GNUC_CONST;
+                                                           const gchar  *name) G_GNUC_CONST;
 G_GNUC_INTERNAL void          _xfce_rc_config_set_group   (XfceRc       *rc,
-                                           const gchar  *name);
+                                                           const gchar  *name);
 G_GNUC_INTERNAL void          _xfce_rc_config_delete_entry(XfceRc       *rc,
-                                           const gchar  *key,
-                                           gboolean      global);
+                                                           const gchar  *key,
+                                                           gboolean      global);
 G_GNUC_INTERNAL gboolean      _xfce_rc_config_has_entry   (const XfceRc *rc,
-                                           const gchar  *key) G_GNUC_CONST;
+                                                           const gchar  *key) G_GNUC_CONST;
 G_GNUC_INTERNAL const gchar*  _xfce_rc_config_read_entry  (const XfceRc *rc,
-                                           const gchar  *key,
-                                           gboolean      translated) G_GNUC_CONST;
+                                                           const gchar  *key,
+                                                           gboolean      translated) G_GNUC_CONST;
 G_GNUC_INTERNAL void          _xfce_rc_config_write_entry (XfceRc       *rc,
-                                           const gchar  *key,
-                                           const gchar  *value);
+                                                           const gchar  *key,
+                                                           const gchar  *value);
 
 
 #endif /* !__LIBXFCE4UTIL_XFCE_RC_PRIVATE_H__ */
